/*
Copyright (©) 2003-2025 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/


#pragma once

#include <config/libraries.h>

class Webserver_Request;

constexpr const char* application_x_www_form_urlencoded {"application/x-www-form-urlencoded"};
constexpr const char* text_plain {"text/plain"};
constexpr const char* multipart_form_data {"multipart/form-data"};

bool http_parse_header (std::string header, Webserver_Request& webserver_request);
void http_parse_post (std::string content, Webserver_Request& webserver_request);
void http_assemble_response (Webserver_Request& webserver_request);
void http_stream_file (Webserver_Request& webserver_request, bool enable_cache);
std::string http_parse_host (const std::string & line);
